==> deepin-log-viewer_6.1.8.tar.xz: BUILD/translations/deepin-log-viewer_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리자에 표시</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>로그 지우기</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>새로 고침</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>로그를 지우시겠습니까?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>모두</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>오늘</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3일</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1주</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1달</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3달</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>내보내기</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>모두</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>긴급</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>알림</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>위기</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>공지</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>디버그</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>로그인</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>시동</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>컴퓨터 끄기</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html))</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>내보내는 중...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>내보내기 성공</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>파일 내보내기</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>기간:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>레벨:</translation>
    </message>
    <message>
        <source>Application list:</source>
        <translation>응용프로그램 목록:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>상태:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>이벤트 유형:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>사용자:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>작업:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>사용자 이름:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>부트 레코드</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>컴퓨터 끄기 기록</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>로그인 기록</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>디버그</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>긴급</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>알림</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>위기</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>공지</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>로그 파일이 비어 있음</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>로그 보기도구</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>로그 보기도구는 시스템 로그를 볼 수 있는 유용한 도구입니다.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>검색 결과 없음</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>레벨</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>프로세스</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>날짜 및 시간</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>User</source>
        <translation>사용자</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>원본</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>작업</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>상태</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>이벤트 유형</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자이름</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>레벨:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>프로세스:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>날짜 및 시간:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>정보:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>사용자:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>날짜 및 시간</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>시스템 로그</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>커널 로그</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>시동 로그</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg 로그</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin 로그</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg 로그</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>응용프로그램 로그</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>컴퓨터 시동-종료 이벤트</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-log-viewer_6.1.15.tar.xz: BUILD/translations/deepin-log-viewer_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ko">
<context>
    <name>Action</name>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리자에 표시</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation>로그 지우기</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>새로 고침</translation>
    </message>
    <message>
        <source>Are you sure you want to clear the log?</source>
        <translation>로그를 지우시겠습니까?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>Button</name>
    <message>
        <source>All</source>
        <translation>모두</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>오늘</translation>
    </message>
    <message>
        <source>3 days</source>
        <translation>3일</translation>
    </message>
    <message>
        <source>1 week</source>
        <translation>1주</translation>
    </message>
    <message>
        <source>1 month</source>
        <translation>1달</translation>
    </message>
    <message>
        <source>3 months</source>
        <translation>3달</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>내보내기</translation>
    </message>
</context>
<context>
    <name>ComboBox</name>
    <message>
        <source>All</source>
        <translation>모두</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>긴급</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>알림</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>위기</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>공지</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>디버그</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>로그인</translation>
    </message>
    <message>
        <source>Boot</source>
        <translation>시동</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>컴퓨터 끄기</translation>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identity authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Discretionary Access Control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Mandatory access control</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Document audit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DisplayContent</name>
    <message>
        <source>zip(*.zip)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</source>
        <translation>TEXT (*.txt);; Doc (*.doc);; Xls (*.xls);; Html (*.html)</translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>Exporting...</source>
        <translation>내보내는 중...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
</context>
<context>
    <name>ExportMessage</name>
    <message>
        <source>Export successful</source>
        <translation>내보내기 성공</translation>
    </message>
    <message>
        <source>Export failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The export directory is not available. Please choose another directory for the export operation.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>File</name>
    <message>
        <source>Export File</source>
        <translation>파일 내보내기</translation>
    </message>
</context>
<context>
    <name>Label</name>
    <message>
        <source>Period:</source>
        <translation>기간:</translation>
    </message>
    <message>
        <source>Level:  </source>
        <translation>레벨:</translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>상태:</translation>
    </message>
    <message>
        <source>Event Type:</source>
        <translation>이벤트 유형:</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>사용자:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>Action:</source>
        <translation>작업:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>사용자 이름:</translation>
    </message>
    <message>
        <source>Boot record</source>
        <translation>부트 레코드</translation>
    </message>
    <message>
        <source>Shutdown record</source>
        <translation>컴퓨터 끄기 기록</translation>
    </message>
    <message>
        <source>Login record</source>
        <translation>로그인 기록</translation>
    </message>
    <message>
        <source>Audit Type:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Application:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Submodule:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Level</name>
    <message>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <source>Debug</source>
        <translation>디버그</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>오류</translation>
    </message>
    <message>
        <source>Emergency</source>
        <translation>긴급</translation>
    </message>
    <message>
        <source>Alert</source>
        <translation>알림</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>위기</translation>
    </message>
    <message>
        <source>Notice</source>
        <translation>공지</translation>
    </message>
    <message>
        <source>Trace</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Super critical</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogAuthThread</name>
    <message>
        <source>Log file is empty</source>
        <translation>로그 파일이 비어 있음</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Log Viewer</source>
        <translation>로그 보기도구</translation>
    </message>
    <message>
        <source>Log Viewer is a useful tool for viewing system logs.</source>
        <translation>로그 보기도구는 시스템 로그를 볼 수 있는 유용한 도구입니다.</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>No search results</source>
        <translation>검색 결과 없음</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>검색</translation>
    </message>
</context>
<context>
    <name>Table</name>
    <message>
        <source>Level</source>
        <translation>레벨</translation>
    </message>
    <message>
        <source>Process</source>
        <translation>프로세스</translation>
    </message>
    <message>
        <source>Date and Time</source>
        <translation>날짜 및 시간</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>정보</translation>
    </message>
    <message>
        <source>User</source>
        <translation>사용자</translation>
    </message>
    <message>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <source>Source</source>
        <translation>원본</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>작업</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>상태</translation>
    </message>
    <message>
        <source>Event Type</source>
        <translation>이벤트 유형</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>사용자이름</translation>
    </message>
    <message>
        <source>Level:</source>
        <translation>레벨:</translation>
    </message>
    <message>
        <source>Process:</source>
        <translation>프로세스:</translation>
    </message>
    <message>
        <source>Date and Time:</source>
        <translation>날짜 및 시간:</translation>
    </message>
    <message>
        <source>Info:</source>
        <translation>정보:</translation>
    </message>
    <message>
        <source>Null</source>
        <translation>Null</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>사용자:</translation>
    </message>
    <message>
        <source>PID:</source>
        <translation>PID:</translation>
    </message>
    <message>
        <source>File Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SIG</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EXE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Core File</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>User Name </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Offset</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Tbble</name>
    <message>
        <source>Date and Time</source>
        <translation>날짜 및 시간</translation>
    </message>
</context>
<context>
    <name>Tree</name>
    <message>
        <source>System Log</source>
        <translation>시스템 로그</translation>
    </message>
    <message>
        <source>Kernel Log</source>
        <translation>커널 로그</translation>
    </message>
    <message>
        <source>Boot Log</source>
        <translation>시동 로그</translation>
    </message>
    <message>
        <source>dpkg Log</source>
        <translation>dpkg 로그</translation>
    </message>
    <message>
        <source>Kwin Log</source>
        <translation>Kwin 로그</translation>
    </message>
    <message>
        <source>Xorg Log</source>
        <translation>Xorg 로그</translation>
    </message>
    <message>
        <source>Application Log</source>
        <translation>응용프로그램 로그</translation>
    </message>
    <message>
        <source>Boot-Shutdown Event</source>
        <translation>컴퓨터 시동-종료 이벤트</translation>
    </message>
    <message>
        <source>dnf Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Audit Log</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Coredump Log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Waring</name>
    <message>
        <source>Unable to obtain crash information, please install systemd-coredump.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Warning</name>
    <message>
        <source>You do not have permission to view it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security level for the current system: high
 audit only administrators can view the audit log</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Export logs to the specified path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PATH</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified types</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs of specified self-developed applications</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SELF APPNAME</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified time period</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PERIOD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs within a specified debug level</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>LEVEL</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>BOOT STATUS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot(no-klu) logs within a specified status</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export boot-shutdown-event or audit logs within a specified event type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>EVENT TYPE</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on keywords search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KEY WORD</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report coredump informations.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export logs based on app submodel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SUBMODULE</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>titlebar</name>
    <message>
        <source>Refresh interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>10 sec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>5 min</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Export All</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh Now</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
